bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGammaISO.delete
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGammaISO.delete